@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Plack::App::DAIA::Test::Suite;
 {
-  $Plack::App::DAIA::Test::Suite::VERSION = '0.45_1';
+  $Plack::App::DAIA::Test::Suite::VERSION = '0.44';
 }
 #ABSTRACT: Test DAIA Servers via a test scripting language
 
@@ -92,13 +92,11 @@ sub provedaia {
             next;
         } elsif( $_ =~ qr{^([a-z]+)\s*=\s*(.*)}i ) {
             $comment = '';
-            my ($key, $value) = ($1,$2);
             if ($1 =~ /^id[s]?/) {
-                @ids = $value eq '' ? () : ($value);
+                @ids = $2 eq '' ? () : ($2);
             } else {
-                $vars{$key} = $value;
+                $vars{$1} = $2;
             }
-            diag( "$key = $value" ) if $args{verbose};
         } elsif( $_ =~ qr/^\s*{/ ) {
             $json = $_; 
         } else { # identifier
@@ -121,7 +119,7 @@ Plack::App::DAIA::Test::Suite - Test DAIA Servers via a test scripting language
 
 =head1 VERSION
 
-version 0.45_1
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -151,7 +149,7 @@ equivalent to an inital C<server=...> statement in you test suite and the
 latter is equivalent to an initial list of identifiers in you test suite.
 
 If the option C<end> is set, all lines before C<__END__> are ignored in the
-test suite script. The option C<verbose> adds more diagnostic messages.
+test suite script.
 
 =head1 TEST SUITE FORMAT
 
